#ifndef OBJECT_DETECTION_H_
#define OBJECT_DETECTION_H_


#include <opencv2/core/core.hpp>
#include <opencv2/highgui/highgui.hpp>
#include <opencv2/imgproc/imgproc.hpp>

#include <cv_bridge/cv_bridge.h>

#include <ros/ros.h>
#include <image_transport/image_transport.h>
#include <sensor_msgs/image_encodings.h>
#include <sensor_msgs/Image.h>
#include <geometry_msgs/PoseArray.h>
#include <geometry_msgs/Pose.h>
#include <message_filters/time_synchronizer.h>

#include <iostream>
#include <sstream>
#include <math.h>


using namespace std;
using namespace cv;
using namespace message_filters;
//using namespace sensor_msgs;

//static const std::string OPENCV_WINDOW = "Image window";

class ObjectDetection
{
public:
    ros::NodeHandle nh;    
    image_transport::ImageTransport it;
    image_transport::Publisher pub1;
    image_transport::Publisher pub2;
    image_transport::Subscriber subRgb;
    image_transport::Subscriber subDepth;    
    ros::Publisher redObjectsPositionPub;
    ros::Subscriber objectTypeSub;    
    geometry_msgs::PoseArray redObjectsPosition;
    
    int objectType;   
    cv_bridge::CvImagePtr cv_ptr_depth;
    bool isDepthReady;
    
    Object_Detection(): it(nh);
    ~Object_Detection();
    
    void objectTypeCallback(const std_msg::Int& msg); 
    void depthSaving(const sensor_msgs::ImageConstPtr& msg);  
    void rosManagement(const sensor_msgs::ImageConstPtr& msg);
    void rosManagementSynch(const sensor_msgs::ImageConstPtr& rgbImage, const sensor_msgs::ImageConstPtr& depthImage);
    Mat findColoredObject(Mat& input, Mat& colorOnly);
private:
    Mat colorFilter(const Mat& src);
}

#endif